netapp_ontap.models.consistency_group_nvme_host API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_nvme_host`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupNvmeHostSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupNvmeHost object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `dh_hmac_chap: ConsistencyGroupNvmeHostDhHmacChap GET POST`

    A container for the configuration of NVMe in-band authentication using the DH-HMAC-CHAP protocol for a host.

  `nqn: str GET POST`

    The NVMe qualified name (NQN) used to identify the NVMe storage target.

    Example: nqn.1992-01.example.com:string

  `priority: str GET POST`

    The host priority setting allocates appropriate NVMe I/O queues (count and depth) for the host to submit I/O commands. Absence of this property in GET implies io_queue count and I/O queue depth are being used.

    Valid choices:

    - regular
    - high
  `proximity: ConsistencyGroupNvmeHostProximity GET POST PATCH`

    Properties that define the SVMs to which the host is proximal. This information is used to properly report active optimized and active non-optimized network paths using an NVMe controller. If no configuration has been specified for the host, the sub-object is not present in GET requests.
    These properties apply to all instances of the host in the NVMe subsystem in the SVM and its peers.

  `tls: ConsistencyGroupNvmeHostTls GET POST`

    A container for the configuration for NVMe/TCP-TLS transport session for the host.